# yaqd-labjack

[![PyPI](https://img.shields.io/pypi/v/yaqd-labjack)](https://pypi.org/project/yaqd-labjack)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqd-labjack)](https://anaconda.org/conda-forge/yaqd-labjack)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://github.com/yaq-project/yaqd-labjack/-/blob/main/CHANGELOG.md)

yaq daemons for LabJack measurement devices

This package contains the following daemons:

- https://yaq.fyi/daemons/labjack-analog-output
- https://yaq.fyi/daemons/labjack-digital-output
- https://yaq.fyi/daemons/labjack-sensor

Maintainer(s):

- [Blaise Thompson](https://github.com/untzag)
